@@ -2,7 +2,7 @@ from typing import Dict, Any, Union, List
 import datetime
 import re
 
-from .errors import WhoIsQueryError
+from .errors import WhoIsQueryParserError
 
 # Date formats from richardpenman/pywhois
 KNOWN_DATE_FORMATS = [
@@ -28,6 +28,7 @@ KNOWN_DATE_FORMATS = [
     '%d/%m/%Y %H:%M:%S',        # 23/04/2015 12:00:07 EEST
     '%d/%m/%Y %H:%M:%S %Z',     # 23/04/2015 12:00:07 EEST
     '%d/%m/%Y %H:%M:%S.%f %Z',  # 23/04/2015 12:00:07.619546 EEST
+    '%Y-%m-%d %H:%M:%S.%f',     # 23/04/2015 12:00:07.619546
     '%B %d %Y',                 # August 14 2017
     '%d.%m.%Y %H:%M:%S',        # 08.03.2014 10:28:24
     '%a %b %d %Y',              # Tue Dec 12 2000
@@ -77,7 +78,8 @@ class BaseParser:
                     parsed[key] = self._parse_date(parsed.get(key))
         return parsed
 
-    def _parse_date(self, date_string: str) -> Union[datetime.date, str]:
+    @staticmethod
+    def _parse_date(date_string: str) -> Union[datetime.date, str]:
         for date_format in KNOWN_DATE_FORMATS:
             try:
                 date = datetime.datetime.strptime(date_string, date_format)
@@ -110,7 +112,7 @@ class WhoIsParser:
     def parse(self, blob: str) -> None:
         no_match_checks = ['no match', 'not found']
         if any([n in blob.lower() for n in no_match_checks]):
-            raise WhoIsQueryError(f'Domain not found!')
+            raise WhoIsQueryParserError(f'Domain not found!')
         self.parser_output = self._parser.parse(blob)
 
     @staticmethod
@@ -139,6 +141,8 @@ class WhoIsParser:
             return RegexCA()
         elif tld == 'cat':
             return RegexCAT()
+        elif tld == 'cc':
+            return RegexCC()
         elif tld == 'ch':
             return RegexCH()
         elif tld == 'cl':
@@ -556,7 +560,9 @@ class RegexDE(BaseParser):
     """
 
     _de_expressions = {
-        'updated': r'Changed: (\d{4}\.\s\d{2}\.\s\d{2}\.)'
+        'changed': r'Changed: (\d{4}\.\s\d{2}\.\s\d{2}\.)',
+        'name_servers': r'Nserver: *(.+)',
+        'domain_name': r'Domain: *(.+)'
     }
 
     def __init__(self):
@@ -1568,6 +1574,9 @@ class RegexNO(BaseParser):
     _no_expressions = {
         'created': r'Additional information:\nCreated:\s*(.+)',
         'updated': r'Additional information:\n(?:.*\n)Last updated:\s*(.+)',
+        'name_servers': r'Name Server Handle.........: *(.+)',
+        'registrar': r'Registrar Handle...........: *(.+)',
+        'domain_name': r'Domain Name................: *(.+)'
     }
 
     def __init__(self):
@@ -1660,3 +1669,15 @@ class RegexTK(BaseParser):
         super().__init__()
         self.server = 'whois.dot.tk'
         self.update_reg_expressions(self._tk_expressions)
+
+
+class RegexCC(BaseParser):
+    _cc_expressions = {
+        'expires': r'Registrar Registration Expiration Date: (\d{4}-\d{2}-\d{2})',
+        'status': r'Domain Status: *(.+)'
+    }
+
+    def __init__(self):
+        super().__init__()
+        self.server = 'ccwhois.verisign-grs.com'
+        self.update_reg_expressions(self._cc_expressions)
\ No newline at end of file
